ActionSheet class

Constructors

ActionSheet({Key? key, List<ActionSheetItem>? actions, String? title, String? cancelText, String? description, bool round = true, IconData? closeIcon, bool closeOnClickOverlay = true, dynamic onSelect(ActionSheetItem actionSheetItem, int index, BuildContext context)?, dynamic onCancel()?, dynamic onClose()?, Widget? child})
const

Properties

actions → List<ActionSheetItem>?
final
cancelText → String?
final
child → Widget?
final
closeIcon → IconData?
final
closeOnClickOverlay → bool
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
onCancel → dynamic Function()?
final
onClose → dynamic Function()?
final
onSelect → dynamic Function(ActionSheetItem actionSheetItem, int index, BuildContext context)?
final
round → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited