AddressEdit class

Inheritance

Constructors

AddressEdit({Key? key, String areaColumnsPlaceholder = "选择省 / 市 / 区", bool showPostal = true, bool showDelete = false, bool showSetDefault = false, String saveButtonText = "保存", String deleteButtonText = "删除", int detailRows = 1, int detailMaxlength = 200, Map<String, dynamic>? addressInfo, List<Widget>? children, dynamic onSave(Map map)?, dynamic onDelete(Map map)?, dynamic onCancelDelete(Map map)?})

Properties

addressInfo → Map<String, dynamic>?
final
areaColumnsPlaceholder → String
final
children → List<Widget>?
final
deleteButtonText → String
final
detailMaxlength → int
final
detailRows → int
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCancelDelete → dynamic Function(Map map)?
final
onDelete → dynamic Function(Map map)?
final
onSave → dynamic Function(Map map)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveButtonText → String
final
showDelete → bool
final
showPostal → bool
final
showSetDefault → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AddressEdit
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited