AddressInfo class

Constructors

AddressInfo({String? name, String? tel, String? province, String? city, String? county, int? provinceId, int? cityId, int? countyId, String? addressDetail, String? postalCode, bool? isDefault})

Properties

addressDetail → String?
final
city → String?
final
cityId → int?
final
county → String?
final
countyId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
isDefault → bool?
final
name → String?
final
postalCode → String?
final
province → String?
final
provinceId → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tel → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited