AddressList class

Inheritance

Constructors

AddressList({Key? key, int? id, List<AddressInfo>? list, List<AddressInfo>? disabledList, String disabledText = "以下地址超出配送范围", bool switchable = true, String addButtonText = "新增地址", String defaultTagText = "默认", dynamic onAdd()?, dynamic onEdit(AddressInfo info, int i)?, dynamic onSelect(AddressInfo info, int i)?, Widget? top, Widget? children})

Properties

addButtonText → String
final
children → Widget?
final
defaultTagText → String
final
disabledList → List<AddressInfo>?
final
disabledText → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
list → List<AddressInfo>?
final
onAdd → dynamic Function()?
final
onEdit → dynamic Function(AddressInfo info, int i)?
final
onSelect → dynamic Function(AddressInfo info, int i)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
switchable → bool
final
top → Widget?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AddressList
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited