NButton class

Inheritance

Constructors

NButton({Key? key, String type = "default", String size = "normal", String? text, double? width, double? height, dynamic color, Color? textColor, Widget? icon, bool block = false, bool plain = false, bool square = false, bool round = false, bool disabled = false, bool hairline = false, bool loading = false, EdgeInsets? padding, BorderRadius? borderRadius, dynamic onClick()?})

Properties

block → bool
final
borderRadius → BorderRadius?
final
color → dynamic
final
colors → Map<String, dynamic>
final
disabled → bool
final
hairline → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
icon → Widget?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading → bool
final
onClick → dynamic Function()?
final
padding → EdgeInsets?
final
plain → bool
final
round → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → String
final
sizes → Map<String, dynamic>
final
square → bool
final
text → String?
final
textColor → Color?
final
type → String
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildContent() → Widget
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited