Calendar class

Constructors

Calendar({Key? key, String type = "single", String title = "日期选择", Color? color, DateTime? minDate, DateTime? maxDate, dynamic defaultDate, double rowHeight = Style.calendarDayHeight, bool poppable = true, bool round = true, bool showMark = true, bool showConfirm = true, bool closeOnClickOverlay = true, String confirmText = "确定", double height = Style.calendarHeight, dynamic onSelect(dynamic date)?, dynamic onConfirm(dynamic date)?})
const

Properties

closeOnClickOverlay → bool
final
color → Color?
final
confirmText → String
final
defaultDate → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
maxDate → DateTime?
final
minDate → DateTime?
final
onConfirm → dynamic Function(dynamic date)?
final
onSelect → dynamic Function(dynamic date)?
final
poppable → bool
final
round → bool
final
rowHeight → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showConfirm → bool
final
showMark → bool
final
title → String
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited