CheckItem class

Constructors

CheckItem({String? name, bool value = false, String shape = 'round', String? text, bool disabled = false, double iconSize = Style.checkboxSize, Color checkedColor = Style.checkboxCheckedIconColor})

Properties

checkedColor → Color
final
disabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
iconSize → double
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → String
final
text → String?
final
value → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited