CoupenItem class

Constructors

CoupenItem({String? name, String? condition, String? startAt, String? endAt, String? description, String? reason, double? value, String? valueDesc, String? unitDesc})

Properties

condition → String?
final
description → String?
final
endAt → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
reason → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAt → String?
final
unitDesc → String?
final
value → double?
final
valueDesc → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited