Coupon class

Constructors

Coupon({Key? key, int? chosenCoupon, List<CoupenItem>? coupons, List<CoupenItem>? disabledCoupons, String enabledTitle = "可使用优惠券", String disabledTitle = "不可使用优惠券", String exchangeButtonText = "兑换", bool exchangeButtonDisabled = false, int exchangeMaxLength = 10, int? displayedCouponIndex, bool showCloseButton = true, String closeButtonText = "不使用优惠", String inputPlaceholder = "请输入优惠码", bool showExchangeBar = true, Image? emptyImage, dynamic onSelect(int val)?, dynamic onExchange(String val)?})

Properties

chosenCoupon → int?
final
closeButtonText → String
final
coupons → List<CoupenItem>?
final
disabledCoupons → List<CoupenItem>?
final
disabledTitle → String
final
displayedCouponIndex → int?
final
emptyImage → Image?
final
enabledTitle → String
final
exchangeButtonDisabled → bool
final
exchangeButtonText → String
final
exchangeMaxLength → int
final
hashCode → int
The hash code for this object.
no setterinherited
inputPlaceholder → String
final
onExchange → dynamic Function(String val)?
final
onSelect → dynamic Function(int val)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCloseButton → bool
final
showExchangeBar → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited