NDialog class

自定义Dialog

Inheritance

Constructors

NDialog({Key? key, String? title, String? message, AlignmentDirectional titleAlign = AlignmentDirectional.center, TextAlign messageAlign = TextAlign.center, bool showConfirmButton = true, bool showCancelButton = false, String confirmButtonText = "确认", Color confirmButtonColor = Style.dialogBackgroundColor, Color confirmTextColor = Style.dialogConfirmButtonTextColor, String cancelButtonText = "取消", Color cancelButtonColor = Style.dialogBackgroundColor, Color cancelTextColor = Style.dialogCancelButtonTextColor, bool closeOnClickOverlay = false, dynamic onConfirm()?, dynamic onCancel()?, Future<bool> beforeClose()?, Widget? child})
const

Properties

beforeClose → Future<bool> Function()?
final
cancelButtonColor → Color
final
cancelButtonText → String
final
cancelTextColor → Color
final
child → Widget?
final
closeOnClickOverlay → bool
final
confirmButtonColor → Color
final
confirmButtonText → String
final
confirmTextColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message → String?
final
messageAlign → TextAlign
final
onCancel → dynamic Function()?
final
onConfirm → dynamic Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCancelButton → bool
final
showConfirmButton → bool
final
title → String?
final
titleAlign → AlignmentDirectional
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _NDialog
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited