Field class

Inheritance

Constructors

Field({Key? key, TextInputType? keyboardType, FocusNode? focusNode, TextInputAction textInputAction = TextInputAction.done, String? label, String? placeholder, TextEditingController? controller, int? maxLength, bool disabled = false, bool readonly = false, bool require = false, bool clearable = true, bool autofocus = false, List<TextInputFormatter>? inputFormatters, String type = "text", int rows = 2, bool showWordLimit = false, bool error = false, String? errorMessage, double labelWidth = Style.fieldLabelWidth, TextAlign labelAlign = TextAlign.start, TextAlign inputAlign = TextAlign.start, IconData? leftIcon, dynamic clickLeft()?, IconData? rightIcon, dynamic clickRight()?, Widget? right, ToolbarOptions? toolbarOptions, dynamic onChange(String val)?, dynamic onEditingComplete()?, dynamic onSubmitted(String val)?, dynamic onClick()?, TextStyle? style})

Properties

autofocus → bool
final
clearable → bool
final
clickLeft → dynamic Function()?
final
clickRight → dynamic Function()?
final
controller → TextEditingController?
final
disabled → bool
final
error → bool
final
errorMessage → String?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
inputAlign → TextAlign
final
inputFormatters → List<TextInputFormatter>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
label → String?
final
labelAlign → TextAlign
final
labelWidth → double
final
leftIcon → IconData?
final
maxLength → int?
final
onChange → dynamic Function(String val)?
final
onClick → dynamic Function()?
final
onEditingComplete → dynamic Function()?
final
onSubmitted → dynamic Function(String val)?
final
placeholder → String?
final
readonly → bool
final
require → bool
final
final
rightIcon → IconData?
final
rows → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showWordLimit → bool
final
style → TextStyle?
final
textInputAction → TextInputAction
final
toolbarOptions → ToolbarOptions?
final
type → String
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _Field
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited