ActionButtonItem class

Constructors

ActionButtonItem({String? text, IconData? icon, String? info, dynamic onClick()?, Widget? customIcon, Widget? customText})

Properties

customIcon → Widget?
final
customText → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
final
info → String?
final
onClick → dynamic Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited