ButtonItem class

Constructors

ButtonItem({String? text, dynamic color, bool disabled = false, bool loading = false, dynamic onClick()?, Widget? customText})

Properties

color → dynamic
final
customText → Widget?
final
disabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
loading → bool
final
onClick → dynamic Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited