NumberKeyboard class

Constructors

NumberKeyboard({String? value = "", String? title, int? maxlength, String? extraKey, String? closeButtomText, String deleteButtonText = "删除", bool showDeleteKey = true, dynamic onChange(String val)?, dynamic onSubmitted(String val)?, dynamic onClose()?})

Properties

closeButtomText → String?
final
deleteButtonText → String
final
extraKey → String?
final
hashCode → int
The hash code for this object.
no setterinherited
maxlength → int?
final
onChange → dynamic Function(String val)?
final
onClose → dynamic Function()?
final
onSubmitted → dynamic Function(String val)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDeleteKey → bool
final
title → String?
final
value → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited