Picker class

Inheritance

Constructors

Picker({Key? key, List<PickerItem>? colums, bool showToolbar = false, String toolbarPosition = "top", String? title, bool loading = false, double itemHeight = 44.0, String confirmButtonText = "确认", String cancelButtonText = "取消", dynamic defaultIndex, int level = 1, dynamic onConfirm(List<String?> selectedValues, dynamic selectedIndex)?, dynamic onCancel(List<String?> selectedValues, dynamic selectedIndex)?, dynamic onChange(List<String?> selectedValues, dynamic selectedIndex)?})
const

Properties

cancelButtonText → String
final
colums → List<PickerItem>?
final
confirmButtonText → String
final
defaultIndex → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
itemHeight → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
level → int
final
loading → bool
final
onCancel → dynamic Function(List<String?> selectedValues, dynamic selectedIndex)?
final
onChange → dynamic Function(List<String?> selectedValues, dynamic selectedIndex)?
final
onConfirm → dynamic Function(List<String?> selectedValues, dynamic selectedIndex)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showToolbar → bool
final
title → String?
final
toolbarPosition → String
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _Picker
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited