Search class

Inheritance

Constructors

Search({Key? key, String shape = "square", Color? background, int maxLength = 100, String placeholder = "请输入搜索关键词", bool clearable = true, bool showAction = false, String actionText = "取消", bool disabled = false, bool readonly = false, IconData leftIcon = Icons.search, IconData? rightIcon, Widget? left, Widget? right, dynamic onClickLeft()?, dynamic onClickRight()?, dynamic onCancel()?, dynamic onSubmitted(String val)?})

Properties

actionText → String
final
background → Color?
final
clearable → bool
final
disabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
left → Widget?
final
leftIcon → IconData
final
maxLength → int
final
onCancel → dynamic Function()?
final
onClickLeft → dynamic Function()?
final
onClickRight → dynamic Function()?
final
onSubmitted → dynamic Function(String val)?
final
placeholder → String
final
readonly → bool
final
final
rightIcon → IconData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → String
final
showAction → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _Search
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited