Swipe class

Inheritance

Constructors

Swipe({required List<Widget> children, Duration? interval, bool autoPlay = false, int? initialSwipe = 0, double indicatorSize = Style.swipeIndicatorSize, Curve curve = Curves.fastOutSlowIn, Duration? duration, bool showIndicators = true, String scrollDirection = 'horizontal', double viewportFraction = 1.0, Color indicatorColor = Style.swipeIndicatorActiceBackgroundColor, dynamic onChange(int val)?, Widget? indicator})

Properties

autoPlay → bool
final
children → List<Widget>
final
curve → Curve
final
duration → Duration?
final
hashCode → int
The hash code for this object.
no setterinherited
indicator → Widget?
final
indicatorColor → Color
final
indicatorSize → double
final
initialSwipe → int?
final
interval → Duration?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChange → dynamic Function(int val)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → String
final
showIndicators → bool
final
viewportFraction → double
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _Swipe
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited